@@ -7,6 +7,7 @@
 # published by the Free Software Foundation.
 
 import struct
+import codecs
 from struct import unpack, pack
 
 from .._compat import text_type, chr_, PY3, swap_to_string, string_types, \
@@ -411,6 +412,8 @@ class FrameIDSpec(StringSpec):
 
 class BinaryDataSpec(Spec):
 
+    handle_nodata = True
+
     def __init__(self, name, default=b""):
         super(BinaryDataSpec, self).__init__(name, default)
 
@@ -435,6 +438,22 @@ class BinaryDataSpec(Spec):
         return value
 
 
+def iter_text_fixups(data, encoding):
+    """Yields a series of repaired text values for decoding"""
+
+    yield data
+    if encoding == Encoding.UTF16BE:
+        # wrong termination
+        yield data + b"\x00"
+    elif encoding == Encoding.UTF16:
+        # wrong termination
+        yield data + b"\x00"
+        # utf-16 is missing BOM, content is usually utf-16-le
+        yield codecs.BOM_UTF16_LE + data
+        # both cases combined
+        yield codecs.BOM_UTF16_LE + data + b"\x00"
+
+
 class EncodedTextSpec(Spec):
 
     _encodings = {
@@ -449,19 +468,21 @@ class EncodedTextSpec(Spec):
 
     def read(self, header, frame, data):
         enc, term = self._encodings[frame.encoding]
-        try:
-            # allow missing termination
-            return decode_terminated(data, enc, strict=False)
-        except ValueError:
-            # utf-16 termination with missing BOM, or single NULL
-            if not data[:len(term)].strip(b"\x00"):
-                return u"", data[len(term):]
-
-            # utf-16 data with single NULL, see issue 169
+        err = None
+        for data in iter_text_fixups(data, frame.encoding):
             try:
-                return decode_terminated(data + b"\x00", enc)
-            except ValueError:
-                raise SpecError("Decoding error")
+                value, data = decode_terminated(data, enc, strict=False)
+            except ValueError as e:
+                err = e
+            else:
+                # Older id3 did not support multiple values, but we still
+                # read them. To not missinterpret zero padded values with
+                # a list of empty strings, stop if everything left is zero.
+                # https://github.com/quodlibet/mutagen/issues/276
+                if header.version < header._V24 and not data.strip(b"\x00"):
+                    data = b""
+                return value, data
+        raise SpecError(err)
 
     def write(self, config, frame, value):
         enc, term = self._encodings[frame.encoding]
